ll-toxic
========

Generate Oracle functions from PL/SQL embedded in XML.

For documentation read ``toxic.py``.

For requirements and installation instructions read ``INSTALL.rst``.

For a list of new features and bugfixes read ``NEWS.rst``.

For the license read ``toxic.py``.

ll-toxic is available from ftp://ftp.livinglogic.de/pub/livinglogic/toxic/

Web pages can be found at http://www.livinglogic.de/Python/toxic/

-- Walter Dörwald <walter@livinglogic.de>
